wifiPassword
============

.. image:: https://travis-ci.org/ankitjain28may/wifiPassword.svg?branch=master
   :target: https://travis-ci.org/ankitjain28may/wifiPassword
.. image:: https://img.shields.io/pypi/v/wifiPassword.svg
   :target: https://pypi.python.org/pypi/wifiPassword
.. image:: https://img.shields.io/pypi/dm/wifiPassword.svg
   :target: https://pypi.python.org/pypi/wifiPassword
.. image:: https://landscape.io/github/ankitjain28may/wifiPassword/master/landscape.svg?style=flat-square
   :target: https://landscape.io/github/ankitjain28may/wifiPassword/master

A cross platform CLI tool to get connected wifi network's password.

Installation
~~~~~~~~~~~~

-  Using ``pip``

   .. code:: shell

       $ pip install wifiPassword

-  From source

   .. code:: shell

       $ git clone https://github.com/ankitjain28may/wifiPassword
       $ cd wifiPassword
       $ python setup.py install


Usage
~~~~~
::
       wifiPassword [wifi_name]

       wifiPassword -h <help>

Note : If you won't give wifi_name, it selects the profile of the connected network by default

License
~~~~~~~

Copyright (c) 2016 Ankit Jain - Released under MIT License

P.S For more python scripts Go To ->
`pythonResources <https://github.com/ankitjain28may/pythonResources>`__